==> ejc-sealm-impl-3.0.0-20220105.115534-11-sources.jar: com/ejianc/business/sealm/service/impl/YzhsBpmServiceImpl.java <==
package com.ejianc.business.sealm.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.sealm.bean.YzffEntity;
import com.ejianc.business.sealm.bean.YzhsEntity;
import com.ejianc.business.sealm.service.IYzhsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("yzhs") 
public class YzhsBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IYzhsService service;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		if (billId !=null){
			YzhsEntity yzhsEntity =service.selectById(billId);
			if (yzhsEntity!=null){
				LambdaUpdateWrapper<YzhsEntity> wrapper = new LambdaUpdateWrapper<>();
				wrapper.set(YzhsEntity::getZt, 0);
				//	wrapper.set(TrainXxgzEntity::getIsStop, BidCommonConsts.YES);
				service.update(wrapper);
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		if (billId !=null){
			YzhsEntity yzhsEntity =service.selectById(billId);
			if (yzhsEntity!=null){
				LambdaUpdateWrapper<YzhsEntity> wrapper = new LambdaUpdateWrapper<>();
				wrapper.set(YzhsEntity::getZt, 5);
				//	wrapper.set(TrainXxgzEntity::getIsStop, BidCommonConsts.YES);
				service.update(wrapper);
			}
		}
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-sealm-impl-3.0.0-20220107.081216-19-sources.jar: com/ejianc/business/sealm/service/impl/YzhsBpmServiceImpl.java <==
package com.ejianc.business.sealm.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.sealm.bean.YzdjEntity;
import com.ejianc.business.sealm.bean.YzffEntity;
import com.ejianc.business.sealm.bean.YzhsEntity;
import com.ejianc.business.sealm.consts.SealmYzztConsts;
import com.ejianc.business.sealm.service.IYzdjService;
import com.ejianc.business.sealm.service.IYzffService;
import com.ejianc.business.sealm.service.IYzhsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("yzhs") 
public class YzhsBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IYzhsService service;

	@Autowired
	private IYzffService yzffService;
	@Autowired
	private IYzdjService yzdjService;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		if (billId !=null){
			YzhsEntity yzhsEntity =service.selectById(billId);
			if (yzhsEntity!=null){
				LambdaUpdateWrapper<YzdjEntity> wrapper = new LambdaUpdateWrapper<>();
				wrapper.set(YzdjEntity::getZt, SealmYzztConsts.ZBZK);
				wrapper.eq(YzdjEntity::getBillCode,yzhsEntity.getYzbhCode());
				//	wrapper.set(TrainXxgzEntity::getIsStop, BidCommonConsts.YES);
				yzdjService.update(wrapper);
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		if (billId !=null){
			YzhsEntity yzhsEntity =service.selectById(billId);
			if (yzhsEntity!=null){
				LambdaUpdateWrapper<YzdjEntity> wrapper = new LambdaUpdateWrapper<>();
				wrapper.set(YzdjEntity::getZt, SealmYzztConsts.YC);
				wrapper.eq(YzdjEntity::getBillCode,yzhsEntity.getYzbhCode());
				yzdjService.update(wrapper);
			}
		}
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
        YzhsEntity yzhsEntity =service.selectById(billId);
		LambdaUpdateWrapper<YzdjEntity> wrapper = new LambdaUpdateWrapper<>();
		wrapper.set(YzdjEntity::getDqbgrId,yzhsEntity.getHsbgrId());
		wrapper.set(YzdjEntity::getDqbgrName,yzhsEntity.getHsbgrName());
		wrapper.eq(YzdjEntity::getBillCode,yzhsEntity.getYzbhCode());
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
